@@ -24,4 +24,7 @@
 # Boston, MA 02110-1301, USA.
 
 # Import from pygit2
-from ._libgit2 import ffi, lib as C  # noqa: F401
+from ._libgit2 import ffi  # noqa: F401
+from ._libgit2 import lib as C  # type: ignore # noqa: F401
+
+__all__ = ['C', 'ffi']
